@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import csv
 import os
+import pathlib
 import shutil
 import subprocess
 import zipfile
@@ -498,6 +499,12 @@ def new_docker_env(
     wdir: Annotated[
         str, typer.Option("--wdir", help="Working directory.")
     ] = "/work",
+    user: Annotated[
+        str,
+        typer.Option(
+            "--user", help="User account to use to run the container."
+        ),
+    ] = None,
     platform: Annotated[
         str, typer.Option("--platform", help="Which platform(s) to build for.")
     ] = None,
@@ -563,6 +570,8 @@ def new_docker_env(
         env["layers"] = layers
     if platform:
         env["platform"] = platform
+    if user:
+        env["user"] = user
     envs[name] = env
     ck_info["environments"] = envs
     with open("calkit.yaml", "w") as f:
@@ -859,7 +868,7 @@ def new_publication(
     elif overwrite and pub_fpath in pub_paths:
         pubs = [p for p in pubs if p.get("path") != pub_fpath]
     pub = dict(
-        path=pub_fpath,
+        path=pathlib.Path(pub_fpath).as_posix(),
         kind=kind,
         title=title,
         description=description,
@@ -1286,7 +1295,7 @@ def new_status(
     now = calkit.utcnow(remove_tz=False)
     # Append to end of CSV
     write_header = not os.path.isfile(fpath)
-    with open(fpath, "a") as f:
+    with open(fpath, "a", newline="") as f:
         writer = csv.writer(f)
         if write_header:
             writer.writerow(["timestamp", "status", "message"])
